package VMOMI::HostGraphicsConfigSharedPassthruAssignmentPolicy;
use parent 'VMOMI::SimpleType';

use strict;
use warnings;

1;
